#' Map matrix indices to coordinates.
#'
#' \code{matrix.map} Maps the index of a matrix to the row and column 
#' coordinates, given the dimensions of the matrix.
#'
#' This is intended as a helper function for the \code{\link{GridGraph}} package.
#' It may be of use in other situations when working with matrices.
#' 
#' The function assumes the matrix is filled by column (the default behaviour 
#' in R, see \code{\link[base]{matrix}}).
#' 
#' This function is vectorised, so that \code{n} can be a vector.
#'
#' @param n The index of a cell (or cells) in the matrix.
#' @param dim.m A numeric vector of length 2 containing the dimesions (rows, 
#' columns) of the matrix (as returned by \code{\link[base]{dim}}).
#' @return A list of length 2 containing the named vectors 'row' and 'col' each 
#' of the same length as \code{n}.
#'
#' @export
matrix.map = function(n, dim.m){
  col = ceiling(n / dim.m[1])
  row = n - ((col - 1) * dim.m[1])
  outofbounds = col < 1 | col > dim.m[2] | row < 1 | row > dim.m[1]
  col[outofbounds] = NA
  row[outofbounds] = NA
  return(list(row=row, col=col))
}
