#' Map matrix coordinates to indices.
#'
#' \code{matrix.unmap} Maps the row and column coordinates to the index of a 
#' matrix, given the dimensions of the matrix.
#'
#' This is intended as a helper function for the \code{\link{GridGraph}} package.
#' It may be of use in other situations when working with matrices.
#' 
#' The function assumes the matrix is filled by column (the default behaviour 
#' in R, see \code{\link[base]{matrix}}).
#' 
#' This function is vectorised so that \code{row} and \code{col} can be vectors.
#' The parameters \code{row} and \code{col} must be the same length.
#'
#' @param row The row index of a cell (or cells) in a matrix.
#' @param col The column index of a cell (or cells) in a matrix.
#' @param dim.m A numeric vector of length 2 containing the dimesions (rows, 
#' columns) of the matrix (as returned by \code{\link[base]{dim}}).
#' @return A vector of the same length as 'row' and 'col' corresponding to the 
#' index of the cell(s) when the matrix is considered as a vector.
#'
#' @export
matrix.unmap = function(row, col, dim.m){
  outofbounds = col < 1 | col > dim.m[2] | row < 1 | row > dim.m[1]
  n = ((col - 1) *  dim.m[1]) + row
  n[outofbounds] = NA
  return(n)
}

