% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/layout_grid_centroid_attraction.R
\name{layout.grid.centroid.attraction}
\alias{layout.grid.centroid.attraction}
\title{Grid-constrained layout of network vertices.}
\usage{
layout.grid.centroid.attraction(distance.matrix, threshold,
  row.size.factor = 1, col.size.factor = 1, increment = 0.5,
  extend = NULL, iterations = 1)
}
\arguments{
\item{distance.matrix}{A matrix of \emph{distances} representing an undirected 
weighted network. Distances are smaller for more correlated vertices and can 
be generated by subtracting the Pearson correlation (or equivalent) from 1 
and setting all values above 1 to equal 1.}

\item{threshold}{A threshold below which vertices are considered to be 
connected by an edge.}

\item{row.size.factor}{A factor indicating by how many rows the grid should
be padded (see the details for an explanation).}

\item{col.size.factor}{A factor indicating by how many columns the grid 
should be padded (see the details for an explanation).}

\item{increment}{A value between 0 and 1 determining what proportion of the 
displacement to the centroid the new cell is placed. Larger values will 
speed up, but potentially destabilise, convergence. Default is 0.5 (half the 
displacement).}

\item{extend}{An optional matrix representing the state of a layout (as 
returned by a previous iteration of \code{\link{layout.grid.centroid.attraction}}). 
If provided, this will be taken as the starting state of the current layout. 
In this way, additional iterations can be added to a layout or graphs can be 
made at different time points during layout to observe convergence as an animation.
The default (NULL) will start with a new layout. It is important that the
random seed is set beforehand using \code{\link[base]{set.seed}}.}

\item{iterations}{The number of iterations that should be performed.}
}
\value{
A matrix of indices corresponding to the rows in 
\code{distance.matrix} and NAs for non-vertex cells.
}
\description{
\code{layout.grid.centroid.attraction} Layout of network vertices by 
iterative convergence to the centroid of all neighbours.
}
\details{
This function places each vertex onto a grid such that the Euclidean distance 
between any two cells is optimally close to the weight of the edge connecting 
the corresponding vertices. 
In each iteration of the layout, the centroid of the cells corresponding to 
all neighbor vertices is calculated and the new position of the vertex is 
moved towards this centroid (by a fraction of the distance determined by the 
\code{increment} parameter.
Displaced cells are shuffled along a mapped direct path between target cell 
and source vertex.
After several iterations, cells with converge to a layout where more 
highly-connected vertices are placed in more closely adjacent cells and 
unconnected (orphan) nodes are displaced to the edges.
}
\examples{

\dontrun{
require(GridGraph)
# Trivial example using the "mtcars" data set.
distance.matrix <- 1 - cor(mtcars)
distance.matrix[which(distance.matrix > 1)] <- 1
grid.layout <- layout.grid.centroid.attraction(distance.matrix, 0.8, row.size.factor=4, 
                                               col.size.factor=4, 
                                               iterations=100)
image(t(apply(grid.layout > 0, 2, rev))) # Visualise
}

# See grid.plot for a more involved example.

}
